from distutils.version import LooseVersion

import cms
import django

cms_version = LooseVersion(cms.__version__)


if django.VERSION < (1, 7):
    from django.utils.module_loading import import_by_path
    import_string = import_by_path
    LTE_DJANGO_1_6 = True
else:
    from django.utils.module_loading import import_string  # noqa
    LTE_DJANGO_1_6 = False  # noqa

if django.VERSION < (1, 8):
    LTE_DJANGO_1_7 = True
else:
    LTE_DJANGO_1_7 = False

LTE_CMS_3_3 = cms_version < LooseVersion('3.4')
LTE_CMS_3_4 = cms_version < LooseVersion('3.5')



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from setuptools import setup
from djangocms_text_ckeditor import __version__


INSTALL_REQUIRES = [
    'django-cms>=3.3.0',
    'html5lib>=0.90,!=0.9999,!=0.99999,<0.99999999',
    'Pillow',
]

CLASSIFIERS = [
    'Development Status :: 5 - Production/Stable',
    'Environment :: Web Environment',
    'Framework :: Django',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: BSD License',
    'Operating System :: OS Independent',
    'Programming Language :: Python',
    'Topic :: Communications',
    'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    'Topic :: Internet :: WWW/HTTP :: Dynamic Content :: Message Boards',
    'Programming Language :: Python :: 2.6',
    'Programming Language :: Python :: 2.7',
    'Programming Language :: Python :: 3.3',
    'Programming Language :: Python :: 3.4',
    'Framework :: Django',
    'Framework :: Django :: 1.6',
    'Framework :: Django :: 1.7',
    'Framework :: Django :: 1.8',
]

setup(
    name='djangocms-text-ckeditor',
    version=__version__,
    description='Text Plugin for django CMS with CKEditor support',
    author='Divio AG',
    author_email='info@divio.ch',
    url='https://github.com/divio/djangocms-text-ckeditor',
    packages=[
        'djangocms_text_ckeditor',
        'djangocms_text_ckeditor.migrations',
        'djangocms_text_ckeditor.south_migrations',
        'djangocms_text_ckeditor.templatetags',
    ],
    install_requires=INSTALL_REQUIRES,
    license='LICENSE.txt',
    platforms=['OS Independent'],
    classifiers=CLASSIFIERS,
    long_description=open('README.rst').read(),
    include_package_data=True,
    zip_safe=False,
    test_suite='test_settings.run',
)



from django import template


register = template.Library()


@register.simple_tag(takes_context=True)
def render_plugin_preview(context, plugin):
    content_renderer = context.get('cms_content_renderer')

    if content_renderer:
        content = content_renderer.render_plugin(
            instance=plugin,
            context=context,
            editable=False,
        )
    else:
        content = plugin.render_plugin(context)
    return content
